@@ -31,7 +31,7 @@ class DebugBarController(TGController):
 
     statics = StaticsController()
 
-    @expose('tgext.debugbar.templates.perform_sql')
+    @expose('genshi:tgext.debugbar.templates.perform_sql')
     def perform_sql(self, stmt, params, engine_id, duration, modify=None):
         # Make sure it is a select statement
         if not stmt.lower().lstrip().startswith('select'):
@@ -63,7 +63,7 @@ class DebugBarController(TGController):
             duration=float(duration),
             title=title)
 
-    @expose('tgext.debugbar.templates.perform_ming')
+    @expose('genshi:tgext.debugbar.templates.perform_ming')
     def perform_ming(self, collection, command, params, duration):
         if not command.startswith('find'):
             raise HTTPBadRequest('Not a find statement')
